============
Installation
============

We recommend using conda environment::

    $ conda create -n g2gtools ipython
    $ source activate g2gtools
    (g2gtools) $ conda install -c kbchoi g2gtools

Or if you have virtualenvwrapper installed::

    $ mkvirtualenv g2gtools
    $ pip install g2gtools

Or, at the command line::

    $ easy_install g2gtools

